@@ -1,5 +1,5 @@
 extern crate cmake;
-extern crate gcc;
+extern crate cc;
 extern crate pkg_config;
 
 use std::env;
@@ -57,7 +57,13 @@ fn main() {
 
         // Currently liblibc links to msvcrt which apparently is a dynamic CRT,
         // so we need to turn this off to get it to link right.
-        cfg.define("STATIC_CRT", "OFF");
+        let features = env::var("CARGO_CFG_TARGET_FEATURE")
+                          .unwrap_or(String::new());
+        if features.contains("crt-static") {
+            cfg.define("STATIC_CRT", "ON");
+        } else {
+            cfg.define("STATIC_CRT", "OFF");
+        }
     }
 
     // libgit2 uses pkg-config to discover libssh2, but this doesn't work on
@@ -79,7 +85,7 @@ fn main() {
     // When cross-compiling, we're pretty unlikely to find a `dlltool` binary
     // lying around, so try to find another if it exists
     if windows && !host.contains("windows") {
-        let c_compiler = gcc::Config::new().cargo_metadata(false)
+        let c_compiler = cc::Build::new().cargo_metadata(false)
                                            .get_compiler();
         let exe = c_compiler.path();
         let path = env::var_os("PATH").unwrap_or(OsString::new());
@@ -104,6 +110,7 @@ fn main() {
         cfg.register_dep("OPENSSL");
     } else {
         cfg.define("USE_OPENSSL", "OFF");
+        cfg.define("USE_HTTPS", "OFF");
     }
     if curl {
         cfg.register_dep("CURL");
@@ -114,6 +121,8 @@ fn main() {
     let _ = fs::remove_dir_all(env::var("OUT_DIR").unwrap());
     t!(fs::create_dir_all(env::var("OUT_DIR").unwrap()));
 
+    // Unset DESTDIR or libgit2.a ends up in it and cargo can't find it
+    env::remove_var("DESTDIR");
     let dst = cfg.define("BUILD_SHARED_LIBS", "OFF")
                  .define("BUILD_CLAR", "OFF")
                  .register_dep("Z")
@@ -122,24 +131,14 @@ fn main() {
     // Make sure libssh2 was detected on unix systems, because it definitely
     // should have been!
     if ssh && !msvc {
-        let flags = dst.join("build/CMakeFiles/git2.dir/flags.make");
+        let flags = dst.join("build/src/git2/sys/features.h");
         let mut contents = String::new();
         t!(t!(File::open(flags)).read_to_string(&mut contents));
-        if !contents.contains("-DGIT_SSH") {
+        if !contents.contains("#define GIT_SSH 1") {
             panic!("libgit2 failed to find libssh2, and SSH support is required");
         }
     }
 
-    if target.contains("windows") {
-        println!("cargo:rustc-link-lib=winhttp");
-        println!("cargo:rustc-link-lib=rpcrt4");
-        println!("cargo:rustc-link-lib=ole32");
-        println!("cargo:rustc-link-lib=crypt32");
-        println!("cargo:rustc-link-lib=static=git2");
-        println!("cargo:rustc-link-search=native={}/lib", dst.display());
-        return
-    }
-
     // libgit2 requires the http_parser library for the HTTP transport to be
     // implemented, and it will attempt to use the system http_parser if it's
     // available. Detect this situation and report using the system http parser
@@ -157,6 +156,16 @@ fn main() {
         }
     }
 
+    if target.contains("windows") {
+        println!("cargo:rustc-link-lib=winhttp");
+        println!("cargo:rustc-link-lib=rpcrt4");
+        println!("cargo:rustc-link-lib=ole32");
+        println!("cargo:rustc-link-lib=crypt32");
+        println!("cargo:rustc-link-lib=static=git2");
+        println!("cargo:rustc-link-search=native={}/lib", dst.display());
+        return
+    }
+
     println!("cargo:rustc-link-lib=static=git2");
     println!("cargo:rustc-link-search=native={}", dst.join("lib").display());
     if target.contains("apple") {
@@ -167,11 +176,18 @@ fn main() {
 }
 
 fn register_dep(dep: &str) {
-    match env::var(&format!("DEP_{}_ROOT", dep)) {
-        Ok(s) => {
-            prepend("PKG_CONFIG_PATH", Path::new(&s).join("lib/pkgconfig"));
+    if let Some(s) = env::var_os(&format!("DEP_{}_ROOT", dep)) {
+        prepend("PKG_CONFIG_PATH", Path::new(&s).join("lib/pkgconfig"));
+        return
+    }
+    if let Some(s) = env::var_os(&format!("DEP_{}_INCLUDE", dep)) {
+        let root = Path::new(&s).parent().unwrap();
+        env::set_var(&format!("DEP_{}_ROOT", dep), root);
+        let path = root.join("lib/pkgconfig");
+        if path.exists() {
+            prepend("PKG_CONFIG_PATH", path);
+            return
         }
-        Err(..) => {}
     }
 }
 
